function [sumSlam,dFslam,s]=waveslam(timesteps,incnum,vertpos,velint,zeta_tot,D,time,rho,dt,dL,nvertpos,rel_vel,simtime,Hs,Tp)

U=zeros(nvertpos,1);                       %Velocity during submergence
s=zeros(nvertpos,incnum);               %Submergence
dFslam=zeros(nvertpos,incnum,'single');          %Slamming forces on each node
sumSlam=zeros(incnum,1);
%%%%%%%%%%%%%%%%-Calculating slamming forces on each node-%%%%%%%%%%%%%%%%%

for i=1:incnum
    if zeta_tot(1,i) >= 0               %Slamming force above MWL
        for j=1:nvertpos
                if s(j,i)<=D && vertpos(j,1)<=zeta_tot(1,i) && vertpos(j,1)>=0
                    if s(j,i)==0 && rel_vel(j,i)>0
                        U(j,1)=rel_vel(j,i);  %Constant velocity during submergence
                    end
                    Cs=5.15*((D/(D+19*s(j,i)))+(0.107*s(j,i)/D));
                    dFslam(j,i)=0.5*rho*Cs*D*U(j,1)^2;
                    if i==incnum;
                        %no further submergence, last time step
                    else
                        s(j,i+1)=U(j,1)*dt+s(j,i);
                    end

                elseif s(j,i)>D && vertpos(j,1)<=zeta_tot(1,i) && vertpos(j,1)>=0
                    s(j,i+1)=s(j,i);
                    U(j,1)=0;
                else 
                    s(j,i+1)=0;
                end
        end
    end
    sumSlam(i,1)=dL*trapz(dFslam(:,i));     %Sum of nodal slamming forces on riser
%     sumMor(i,1)=dL*trapz(dFmor(:,i));
%     sumTotal(i,1)=sumSlam(i,1)+sumMor(i,1);
end
% sumslamforce=dt*trapz(sumSlam(:,1));
% for j=1:nel
%     for i=1:tmax+1
%         dFtot(j,i)=dL*(dFslam(j,i)+dFmor(j,i));
%     end
%     sumstripSlam(j,1)=dt*trapz(dFslam(j,:));  
%     sumstripMor(j,1)=dt*trapz(dFmor(j,:));
%     sumstripTot(j,1)=sumstripSlam(j,1)+sumstripMor(j,1);
% end
%figure with time series of slam load and wave profile
waveelslamtimeseries=figure;
dur=incnum;                    %duration of plot length
[AX,H1,H2] = plotyy(time(1:dur,1),zeta_tot(1,1:dur),timesteps(1:dur,1),sumSlam(1:dur,1),'plot');
set(get(AX(1),'Ylabel'),'String','Elevation [m]') 
set(get(AX(2),'Ylabel'),'String','Force [N]') 
xlabel('Time [s]') 
set(H1,'LineWidth',1)
set(H2,'LineWidth',1)
title(['Wave elevation and slamming forces, Hs',num2str(Hs),'Tp',num2str(Tp)])
legend('Wave elevation','Slam force')
fpath=(['W:\Matlab\Hs',num2str(Hs),'TP',num2str(Tp)]);
saveas(waveelslamtimeseries,fullfile(fpath,['waveelslamtimeseriestestHs',num2str(Hs),'Tp',num2str(Tp),'.png']))
% % total force plotted with slam force
% totwaveload=figure;
% hold on
% plot(t,sumTotal(:,1))
% plot(t,sumMor(:,1),'k')
% legend('With slam load','Morison load only')
% xlabel('Time [s]')
% ylabel('Load [N]')
% title('Total wave load, T=12')
% fpath=('C:\Users\Balder\Desktop\Prosjektoppgave\Latex\pics');
% saveas(totwaveload,fullfile(fpath,'totwaveload2.png'))
% % figur med krefter p hver stripe
% farger=figure;
% hold on
% plot(t,dFtot(2075,:),'b')
% plot(t,dFtot(2175,:),'g')
% plot(t,dFtot(2375,:),'r')
% plot(t,(9.81*10^-3)*sumTotal(:,1),'k','LineWidth',1.5)
% legend('4.25m','3.25m','1.25m','Total load [ton]')
% ylabel('Load [N]')
% xlabel('Time [s]')
% title('Wave loads on strips')
% fpath=('C:\Users\Balder\Desktop\Prosjektoppgave\Latex\pics');
% saveas(farger,fullfile(fpath,'forcesonstrips.png'))
% % figure showing only Morison load and combined slamming and Morison load
% % on one strip
% morslam=figure; 
% hold on
% plot(t,dFtot(2375,:),'r')
% plot(t,dFtot(1575,:),'g')
% plot(t,dFtot(3525,:),'b')
% legend('1.25m','9.25m','-10.25')
% ylabel('Load [N]')
% xlabel('Time [s]')
% title('Wave loads on strips')
% fpath=('C:\Users\Balder\Desktop\Prosjektoppgave\Latex\pics');
% saveas(morslam,fullfile(fpath,'morslamstrips.png'))
% %Figure showing slam load on one strip, short time duration
% singleslam=figure; 
% hold on
% plot(t,dL*dFslam(2250,:),'b')
% plot(t,dL*dFslam(2175,:),'k')
% legend('1.25m','1.50m')
% ylabel('Load [N]')
% xlabel('Time [s]')
% axis([9.6 10.6 0 3100]);
% title('Wave loads on strip')
% fpath=('C:\Users\Balder\Desktop\Prosjektoppgave\Latex\pics');
% saveas(singleslam,fullfile(fpath,'singleslam.png'))
% clear sumSlam
disp('waveslam done')
end      




